==> nextcloud-app-deck-1%3A1.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_SV.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "{user} has shared the board %s with you." : "{user} ha compartido el tablero %s contigo. ",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "Done" : "Terminado",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Create new board" : "Crear un nuevo tablero",
    "Cancel" : "Cancelar",
    "File already exists" : "El archivo ya existe",
    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Delete" : "Borrar",
    "Add a new stack" : "Agregar una nueva pila",
    "Add card" : "Agregar tarjeta",
    "Edit" : "Editar",
    "Title" : "Título",
    "Members" : "Miembros",
    "Due date" : "Fecha de vencimiento",
    "Remove due date" : "Eliminar fecha de expiración",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Upload attachment" : "Cargar adjunto",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "(group)" : "(grupo)",
    "seconds ago" : "hace segundos",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido con usted",
    "Settings" : "Configuraciones ",
    "New board title" : "Nuevo título del tablero",
    "Edit board" : "Editar el tablero",
    "Board details" : "Detalles del tablero"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_SV.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "Done" : "Terminado",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Cancel" : "Cancelar",
    "File already exists" : "El archivo ya existe",
    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
    "Add card" : "Agregar tarjeta",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Delete" : "Borrar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Due date" : "Fecha de vencimiento",
    "Remove due date" : "Eliminar fecha de expiración",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "(group)" : "(grupo)",
    "seconds ago" : "hace segundos",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido con usted",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar el tablero",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "This week" : "Esta semana"
},
"nplurals=2; plural=(n != 1);");
